==> plantuml-1.2022.2.tar.gz: plantuml-1.2022.2/src/net/sourceforge/plantuml/ugraphic/color/HColorAbstract.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 */
package net.sourceforge.plantuml.ugraphic.color;

import net.sourceforge.plantuml.ugraphic.UBackground;

abstract class HColorAbstract implements HColor {

	public UBackground bg() {
		return new UBackground() {
			public HColor getBackColor() {
				return HColorAbstract.this;
			}
		};
	}

	@Override
	public HColor lighten(int ratio) {
		return this;
	}

	@Override
	public HColor darken(int ratio) {
		return this;
	}

	@Override
	public HColor reverseHsluv() {
		return this;
	}

	@Override
	public HColor reverse() {
		return this;
	}

	@Override
	public boolean isDark() {
		return true;
	}

	@Override
	public String asString() {
		return "?" + getClass().getSimpleName();
	}
	
	@Override
	public HColor darkSchemeTheme() {
		return this;
	}

}

==> plantuml-1.2022.7.tar.gz: plantuml-1.2022.7/src/net/sourceforge/plantuml/ugraphic/color/HColorAbstract.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 */
package net.sourceforge.plantuml.ugraphic.color;

import net.sourceforge.plantuml.ugraphic.UBackground;

abstract class HColorAbstract implements HColor {

	public UBackground bg() {
		return new UBackground() {
			public HColor getBackColor() {
				return HColorAbstract.this;
			}
		};
	}

	@Override
	public HColor lighten(int ratio) {
		return this;
	}

	@Override
	public HColor darken(int ratio) {
		return this;
	}

	@Override
	public HColor reverseHsluv() {
		return this;
	}

	@Override
	public HColor reverse() {
		return this;
	}

	@Override
	public boolean isDark() {
		return true;
	}

	@Override
	public String asString() {
		return "?" + getClass().getSimpleName();
	}

	@Override
	public HColor darkSchemeTheme() {
		return this;
	}

	@Override
	public HColor withDark(HColor dark) {
		throw new UnsupportedOperationException();
	}

	@Override
	public HColor opposite() {
		throw new UnsupportedOperationException();
	}

}
